%define major   0
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d
#define devstat %%mklibname %%{name} -d -s

Name:           hackrf
Version:        2024.02.1
Release:        %mkrel 2
Summary:        A project to produce a low cost open source software radio platform
Group:          Communications/Radio
License:        GPLv2
# https://github.com/mossmann/hackrf/wiki
URL:            https://github.com/greatscottgadgets/hackrf/wiki
Source0:        https://github.com/greatscottgadgets/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch0:         hackrf-cmake-4.0.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(libusb)
BuildRequires:  systemd
BuildRequires:  pkgconfig(fftw3)

%description
Hardware designs and software for HackRF, a project to produce a low cost, open
source software radio platform.

%package -n %{libname}
Summary:        Library files for %{name}
Requires:       %{name} = %{version}-%{release}

%package -n %{devname}
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%package doc
Requires:       %{name} = %{version}-%{release}
Summary:        Supplemental documentation for HackRF
BuildArch:      noarch

%if %{defined devstat}
%package -n %{devstat}
Summary:        Static libraries for libhackrf
Requires:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-static-devel = %{version}-%{release}

%description -n %{devstat}
Static libraries for libhackrf.

%files -n %{devstat}
%{_libdir}/libhackrf.a
%endif

%description -n %{devname}
Files needed to develop software against libhackrf.

%description -n %{libname}
hackrf library files.

%description doc
Supplemental documentation for HackRF. For more information, visit the wiki at
https://github.com/mossmann/hackrf/wiki

%prep
%autosetup -p1

# Fix "plugdev" nonsense
sed -i -e 's/GROUP="plugdev"/ENV{ID_SOFTWARE_RADIO}="1"/g' host/libhackrf/53-hackrf.rules

%build
%global _vpath_srcdir host
%cmake \
    -DINSTALL_UDEV_RULES=ON \
    -DUDEV_RULES_PATH=%{_udevrulesdir}
%cmake_build

%install
%cmake_install

%if ! %{defined devstat}
rm -f %{buildroot}%{_libdir}/libhackrf.a
%endif

%files
%doc Readme.md
%{_bindir}/hackrf_*
%{_udevrulesdir}/53-hackrf.rules

%files -n %{libname}
%{_libdir}/libhackrf.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/libhackrf/hackrf.h
%{_libdir}/pkgconfig/libhackrf.pc
%{_libdir}/libhackrf.so

%files doc
%doc doc/*


%changelog
* Sun Jul 13 2025 daviddavid <daviddavid> 2024.02.1-2.mga10
+ Revision: 2253871
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Mon Apr 08 2024 barjac <barjac> 2024.02.1-1.mga10
+ Revision: 2056053
- new version 2024.02.1
- new upstream url

* Mon Feb 06 2023 barjac <barjac> 2023.01.1-1.mga9
+ Revision: 1938886
- new version 2023.01.1

* Tue Oct 04 2022 barjac <barjac> 2022.09.1-1.mga9
+ Revision: 1894551
- new version 2022.09.1

* Fri Apr 01 2022 umeabot <umeabot> 2021.03.1-0.2.mga9
+ Revision: 1837841
- Mageia 9 Mass Rebuild

* Tue Apr 27 2021 barjac <barjac> 2021.03.1-0.1.mga9
+ Revision: 1720119
- new version 2021.03.1

* Thu Feb 13 2020 umeabot <umeabot> 2018.01.1-3.mga8
+ Revision: 1512919
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 2018.01.1-2.mga7
+ Revision: 1298161
- Mageia 7 Mass Rebuild

* Mon Jan 29 2018 barjac <barjac> 2018.01.1-1.mga7
+ Revision: 1198043
- new version 2018.10.1

* Sat Oct 14 2017 barjac <barjac> 2017.02.1-1.mga7
+ Revision: 1171714
- new version 2017.02.1

* Sat Jan 28 2017 barjac <barjac> 2015.07.2-3.mga6
+ Revision: 1083706
- fix udev path during build

* Thu Feb 11 2016 umeabot <umeabot> 2015.07.2-2.mga6
+ Revision: 954281
- Mageia 6 Mass Rebuild

* Fri Sep 11 2015 barjac <barjac> 2015.07.2-1.mga6
+ Revision: 876885
- new version 2015.07.2

* Sat Jan 17 2015 barjac <barjac> 2014.08.1-1.mga5
+ Revision: 811099
- Import hackRF based loosely on Fedora with thanks

